@Echo Off

REM author    Eric Roovers
REM date      20 June 1997
REM filename  build.bat
REM usage     build.bat [-d] file [[-d] file ..]
REM email     eric.roovers@pi.net

REM This is BUILD.BAT and here is what it does:

REM     The log makes mention of
REM  Index Bibliography References  Action
REM +-----+------------+----------+-----------------------------------------
REM :  No :     No     :    No    : LaTeX,DVIPS
REM : Yes :     No     :  No/Yes  : LaTeX,MakeIndex,LaTeX,DVIPS
REM :  No :    Yes     :  No/Yes  : LaTeX,BibTeX,LaTeX,LaTeX,DVIPS
REM :  No :     No     :   Yes    : LaTeX,LaTeX,DVIPS
REM : Yes :    Yes     :  No/Yes  : LaTeX,BibTeX,LaTeX,MakeIndex,LaTeX,DVIPS
REM +-----+------------+----------+-----------------------------------------

REM BUILD.BAT will abort after a failure on either of these programs
REM BUILD.BAT also checks the BibTeX output for errors and warnings and
REM if these are found, aborts the file it is currently processing. Note that
REM BUILD.BAT only checks for BibTeX errors/warnings that start with
REM "Error--" or "Warning--".
REM The argument -d tells BUILD.BAT skip DVIPS.
REM In the two variables makeindexoptions and dvipsoptions, you can put your
REM MakeIndex and DVIPS options. If the boolean variable bibtexstop is set
REM to True, BUILD.BAT will abort the TeX file it is currently processing as
REM soon as BibTeX reports errors or warnings.

:Preamble
  Set makeindexoptions=
  Set dvipsoptions=

:Begin
  Set again=False
  Set usedvips=True
  Set bibtexstop=False

  If Not "%1"=="-d" Goto :FirstLaTeXRun
  Set usedvips=False
  Shift
  If "%1"=="" Goto :MissingArgument

:FirstLaTeXRun
  Echo This is BUILD.BAT - [%1.tex]
  Echo --------------------------------------------------------------------

  LaTeX %1
  If ErrorLevel 1 Goto :LaTeXFailure
  Echo --------------------------------------------------------------------

:CheckBibliography
  Find /c "LaTeX Warning: Citation " %1.log > Nul
  If Errorlevel 1 Goto :CheckIndex

:BibTeXRun
  BibTeX %1 > %1.b$$
  If Errorlevel 1 Goto :BibTeXFailure
  Type %1.b$$
  Echo --------------------------------------------------------------------

  Find /c "Error--" %1.b$$ > Nul
  If Errorlevel 1 Find /c "Warning--" %1.b$$ > Nul
  If Errorlevel 1 Goto :SecondLaTeXRun
  Echo ****** BibTeX reports errors/warnings
  If "%bibtexstop%"=="True" Goto :Finish
  Echo/
  Goto :CheckIndex

:SecondLaTeXRun
  LaTeX %1
  If ErrorLevel 1 Goto :LaTeXFailure
  Echo --------------------------------------------------------------------
  Set again=True

:CheckIndex
  Find /c "Writing index file " %1.log > Nul
  If Errorlevel 1 Goto :CheckReferences

:RunMakeIndex
  MakeIndex %makeindexoptions% %1
  If Errorlevel 1 Goto :MakeIndexFailure
  Echo --------------------------------------------------------------------
  Set again=True

:CheckReferences
  Find /c "Rerun to get cross-references " %1.log > Nul
  If Errorlevel 1 Goto :ThirdLaTeXRun
  Set again=True

:ThirdLaTeXRun
  If "%again%"=="False" Goto :RunDVIPS

  LaTeX %1
  If ErrorLevel 1 Goto :LaTeXFailure
  Echo --------------------------------------------------------------------

:RunDVIPS
  If "%usedvips%"=="False" Goto:Finish
  If Not Exist %1.dvi Goto :Finish
  DVIPS %dvipsoptions% %1
  If ErrorLevel 1 Goto :DVIPSFailure
  Echo --------------------------------------------------------------------
  Goto :Finish

:LaTeXFailure
  Echo ****** LaTeX failure
  Goto :Finish

:BibTeXFailure
  Echo ****** BibTeX failure
  Goto :Finish

:MakeIndexFailure
  Echo ****** MakeIndex failure
  Goto :Finish

:DVIPSFailure
  Echo ****** DVIPS failure
  Goto :Finish

:MissingArgument
  Echo ****** Missing argument
  Echo Usage: BUILD.BAT [-d] file [[-d] file ..]
  Echo/
  Pause
  Goto :End

:Finish
  If Exist %1.b$$ Del %1.b$$
  Echo/
  Pause
  If "%2"=="" Goto :End
  Shift
  Goto :Begin

:End
